/******************************************************************************
;  *       @型号                 : MC51F003A4
;  *       @创建日期             : 2022.12.19
;  *       @公司/作者            : SINOMCU.COM-AE
;  *       @晟矽微官网           : http://www.sinomcu.com/
;  *       @版权                 : 2022 晟矽微电 版权所有.
;  *----------------------摘要描述---------------------------------
;  *                                       
******************************************************************************/

#ifndef __LIN_H
#define __LIN_H

#include "MC51F7424_COMMON.h"

/**
LIN Message Frame(LSB first)：FrameHead + Answer data
    FrameHead：Break Field（>=13 bit Dominate Level+ >=1bit Invisibility level inter-frame space)
               +Sync Byte Field(0x55)+inter-byte space
               +PID（6bit ID+2bit check）
                    bit6:P0 = ID0⊕ID1⊕ID2⊕ID4   
                    bit7:P1 = ~(ID3⊕ID4⊕ID ⊕ID1)
    Answer data:Response space +data  +inter-byte space 
               +checksum(stand checksum,check data,used to Diagnostic Frame;enhanced checksum,check data+PID)
*/

/**
Unconditional Frame    :0x00 - 0x3B
Event Triggered Frame  :0x00 - 0x3B
Sporadic Frame         :0x00 - 0x3B
Diagnostic Frame       :0x3C(master request),0x3D(slave answer)
Reserved Frame         :0x3E,0x3F
*/
typedef enum {
  UNCONDITOPMAL_FRAME = 0U,
  EVENT_TRIGGERED_FRAME,
  SPORADIC_FRAME, 
  DIAGNOSTIC_FRAME,
  RESERVED_FRAME
}LINFrameType;

#define LIN_SYNC_CHAR   0x55
#define GET_ID(pid)     (pid & 0x3F)

uint8_t LIN_CaclPID(uint8_t id);
FlagStatus LIN_CheckPID(uint8_t pid);
uint8_t LIN_CaclChecksum(uint8_t pid,uint8_t *buff);
FlagStatus LIN_CompareChecksum(uint8_t *buff);

#endif/* __LIN_H */ 

/******************************** END OF FILE *********************************/
