/******************************************************************************
;  *       @ͺ                 : MC51F7424
;  *       @             : 2022.12.22
;  *       @˾/            : SINOMCU.COM-AE
;  *       @΢           : http://www.sinomcu.com/
;  *       @Ȩ                 : 2022 ΢ Ȩ.
;  *----------------------ժҪ----------------------------------
;  *TIMER0ʼ,ʵʱ(10ms,100ms)                                                  
******************************************************************************/

#include "User_Def.h"

#define  DELAY_10MS_NUM      10                  // unit ms
#define  DELAY_100MS_NUM     100                 // unit ms

SoftTimerStatus DELAY_10MS_FLAG = SF_TIMER_STOP; // defalut soft timer stop
SoftTimerStatus DELAY_100MS_FLAG = SF_TIMER_STOP;

static __IO uint8_t delay_10ms_count=0;
static __IO uint8_t delay_100ms_count=0;
uint16_t timer0_init_value=0;

/**
  * @brief :Get timer frequency division selection
  * @par :None
  * @retval :Clock div
  */
uint8_t  Get_Time0_ClkDiv(void) {
  uint8_t return_value = 1;
  switch(TCON1 & TIME0_CLK_DIV_MASK) {
    case TIME0_CLK_DIV_1:
      return_value= 1;
      break;
    case TIME0_CLK_DIV_2: 
      return_value= 2; 
      break;
    case TIME0_CLK_DIV_8: 
      return_value= 8; 
      break;
    case TIME0_CLK_DIV_16: 
      return_value= 16; 
      break;
    default:
      break; 
  }
  return return_value;
} 

/**
  * @brief 
  * @par :TIME0_CLK_DIV_1,TIME0_CLK_DIV_2,TIME0_CLK_DIV_8,TIME0_CLK_DIV_16
  * @retval :None
  */
void  Set_Time0_ClkDiv(clk_div) {
    TCON1 &= ~TIME0_CLK_DIV_MASK;
    TCON1 |= clk_div; 
} 

/**
  * @brief :Time 0 init
  * @par :timer_HZ
  * @retval :None
  */
void TIM0_Init(uint16_t timer_HZ) {
  uint32_t timer_init_temp=0;

  Time0_16Bit();
  Set_Time0_ClkDiv(TIME0_CLK_DIV_8);

  timer_init_temp = (FSYS_CLOCK / Get_Time0_ClkDiv() ) /timer_HZ;
  timer0_init_value = 65535-timer_init_temp;
  Timer0_Stop();
  TL0 = (uint8_t)timer0_init_value;
  TH0 = (uint8_t)(timer0_init_value>>8);
  Timer0_Start();
  Timer0_IE_En();
}

 /**
  * @brief :Timer0 Interruption function.
  * @par :None
  * @retval :None
  */
void Timer0_ISR(void) interrupt T0_IRQn {
  Timer0_Stop();
  TL0 = (uint8_t)timer0_init_value;
  TH0 = (uint8_t)(timer0_init_value>>8);
  Timer0_Start();

  if(DELAY_10MS_FLAG != SF_TIMER_STOP) {
    delay_10ms_count++;
    if(delay_10ms_count == DELAY_10MS_NUM ) {    // soft timer OV
      delay_10ms_count =0;
      DELAY_10MS_FLAG =SF_TIMER_OV;
    }
  }

  if(DELAY_100MS_FLAG != SF_TIMER_STOP) {
    delay_100ms_count++;
    if(delay_100ms_count == DELAY_100MS_NUM ) {  // soft timer OV
      delay_100ms_count =0;
      DELAY_100MS_FLAG =SF_TIMER_OV;
    }
  }
}

/**
  * @brief  Start soft timer 10ms,clean ov
  * @param  None
  * @retval None
  */
void Start_10MS_SF_Timer(void) {
  DELAY_10MS_FLAG = SF_TIMER_RUN;
}

/**
  * @brief  Stop soft timer 10ms
  * @param  None
  * @retval None
  */
void Stop_10MS_SF_Timer(void) {
  DELAY_10MS_FLAG = SF_TIMER_STOP;
}

/**
  * @brief  Get state timer 10ms
  * @param  None
  * @retval Status of timer 10ms
  */
SoftTimerStatus Get_State_10MS_SF_Timer(void) {
  return DELAY_10MS_FLAG;
}

/**
  * @brief  Start soft timer 100ms,clean ov
  * @param  None
  * @retval None
  */
void Start_100MS_SF_Timer(void) {
  DELAY_100MS_FLAG = SF_TIMER_RUN;
}

/**
  * @brief  Stop soft timer 100ms
  * @param  None
  * @retval None
  */
void Stop_100MS_SF_Timer(void) {
  DELAY_100MS_FLAG = SF_TIMER_STOP;
}

/**
  * @brief  Get state timer 100ms
  * @param  None
  * @retval Status of timer 100ms
  */
SoftTimerStatus Get_State_100MS_SF_Timer(void) {
  return DELAY_100MS_FLAG;
}

/**************************** end of file *********************************************/
